# This file was auto-generated by Fern from our API Definition.

from .types import (
    Accent,
    AddAgentSecretResponseModel,
    AddChapterResponseModel,
    AddKnowledgeBaseResponseModel,
    AddProjectResponseModel,
    AddPronunciationDictionaryResponseModel,
    AddPronunciationDictionaryRulesResponseModel,
    AddSharingVoiceRequest,
    AddVoiceIvcResponseModel,
    AddVoiceResponseModel,
    AddWorkspaceGroupMemberResponseModel,
    AddWorkspaceInviteResponseModel,
    Age,
    AgentBan,
    AgentCallLimits,
    AgentConfigApiModelInput,
    AgentConfigApiModelOutput,
    AgentConfigOverride,
    AgentConfigOverrideConfig,
    AgentMetadataResponseModel,
    AgentPlatformSettingsRequestModel,
    AgentPlatformSettingsResponseModel,
    AgentSummaryResponseModel,
    AgentWorkspaceOverridesInput,
    AgentWorkspaceOverridesOutput,
    AllowlistItem,
    ArrayJsonSchemaPropertyInput,
    ArrayJsonSchemaPropertyInputItems,
    ArrayJsonSchemaPropertyOutput,
    ArrayJsonSchemaPropertyOutputItems,
    AsrConversationalConfig,
    AsrInputFormat,
    AsrProvider,
    AsrQuality,
    AudioNativeCreateProjectResponseModel,
    AudioNativeEditContentResponseModel,
    AudioNativeProjectSettingsResponseModel,
    AudioOutput,
    AudioWithTimestampsResponseModel,
    AuthSettings,
    AuthorizationMethod,
    BanReasonType,
    BodyAddToKnowledgeBaseV1ConvaiAddToKnowledgeBasePost,
    BodyAddToKnowledgeBaseV1ConvaiAgentsAgentIdAddToKnowledgeBasePost,
    BreakdownTypes,
    ChapterContentBlockExtendableNodeResponseModel,
    ChapterContentBlockInputModel,
    ChapterContentBlockResponseModel,
    ChapterContentBlockResponseModelNodesItem,
    ChapterContentBlockResponseModelNodesItem_Other,
    ChapterContentBlockResponseModelNodesItem_TtsNode,
    ChapterContentBlockTtsNodeResponseModel,
    ChapterContentInputModel,
    ChapterContentParagraphTtsNodeInputModel,
    ChapterContentResponseModel,
    ChapterResponse,
    ChapterSnapshotExtendedResponseModel,
    ChapterSnapshotResponse,
    ChapterSnapshotsResponse,
    ChapterState,
    ChapterStatisticsResponse,
    ChapterWithContentResponseModel,
    ChapterWithContentResponseModelState,
    CharacterAlignmentModel,
    CharacterAlignmentResponseModel,
    ClientEvent,
    ClientToolConfigInput,
    ClientToolConfigOutput,
    CloseConnection,
    ConvAiSecretLocator,
    ConvAiStoredSecretDependencies,
    ConvAiStoredSecretDependenciesAgentToolsItem,
    ConvAiStoredSecretDependenciesAgentToolsItem_Available,
    ConvAiStoredSecretDependenciesAgentToolsItem_Unknown,
    ConvAiStoredSecretDependenciesToolsItem,
    ConvAiStoredSecretDependenciesToolsItem_Available,
    ConvAiStoredSecretDependenciesToolsItem_Unknown,
    ConvAiWebhooks,
    ConvAiWorkspaceStoredSecretConfig,
    ConversationChargingCommonModel,
    ConversationConfig,
    ConversationConfigClientOverrideConfigInput,
    ConversationConfigClientOverrideConfigOutput,
    ConversationConfigClientOverrideInput,
    ConversationConfigClientOverrideOutput,
    ConversationDeletionSettings,
    ConversationHistoryAnalysisCommonModel,
    ConversationHistoryEvaluationCriteriaResultCommonModel,
    ConversationHistoryFeedbackCommonModel,
    ConversationHistoryMetadataCommonModel,
    ConversationHistoryMetadataCommonModelPhoneCall,
    ConversationHistoryMetadataCommonModelPhoneCall_Twilio,
    ConversationHistoryTranscriptCommonModel,
    ConversationHistoryTranscriptCommonModelRole,
    ConversationHistoryTranscriptToolCallCommonModel,
    ConversationHistoryTranscriptToolResultCommonModel,
    ConversationHistoryTwilioPhoneCallModel,
    ConversationHistoryTwilioPhoneCallModelDirection,
    ConversationInitiationClientDataConfigInput,
    ConversationInitiationClientDataConfigOutput,
    ConversationInitiationClientDataRequestInput,
    ConversationInitiationClientDataRequestInputDynamicVariablesValue,
    ConversationInitiationClientDataRequestOutput,
    ConversationInitiationClientDataRequestOutputDynamicVariablesValue,
    ConversationInitiationClientDataWebhook,
    ConversationInitiationClientDataWebhookRequestHeadersValue,
    ConversationSignedUrlResponseModel,
    ConversationSummaryResponseModel,
    ConversationSummaryResponseModelStatus,
    ConversationTokenDbModel,
    ConversationTokenPurpose,
    ConversationTurnMetrics,
    ConversationalConfigApiModelInput,
    ConversationalConfigApiModelOutput,
    ConvertChapterResponseModel,
    ConvertProjectResponseModel,
    CreateAgentResponseModel,
    CreateAudioNativeProjectRequest,
    CreatePhoneNumberResponseModel,
    CreatePronunciationDictionaryResponseModel,
    CreateSipTrunkPhoneNumberRequest,
    CreateTwilioPhoneNumberRequest,
    Currency,
    CustomLlm,
    DataCollectionResultCommonModel,
    DeleteChapterResponseModel,
    DeleteDubbingResponseModel,
    DeleteHistoryItemResponse,
    DeleteProjectResponseModel,
    DeleteSampleResponseModel,
    DeleteVoiceResponseModel,
    DeleteWorkspaceGroupMemberResponseModel,
    DeleteWorkspaceInviteResponseModel,
    DependentAvailableAgentIdentifier,
    DependentAvailableAgentIdentifierAccessLevel,
    DependentAvailableAgentToolIdentifier,
    DependentAvailableAgentToolIdentifierAccessLevel,
    DependentAvailableToolIdentifier,
    DependentAvailableToolIdentifierAccessLevel,
    DependentPhoneNumberIdentifier,
    DependentUnknownAgentIdentifier,
    DependentUnknownAgentToolIdentifier,
    DependentUnknownToolIdentifier,
    DoDubbingResponse,
    DocumentUsageModeEnum,
    DubbedSegment,
    DubbingMediaMetadata,
    DubbingMediaReference,
    DubbingMetadataResponse,
    DubbingResource,
    DynamicVariablesConfig,
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
    EditChapterResponseModel,
    EditProjectResponseModel,
    EditVoiceResponseModel,
    EditVoiceSettingsResponseModel,
    EmbedVariant,
    EmbeddingModelEnum,
    EvaluationSettings,
    EvaluationSuccessResult,
    ExtendedSubscriptionResponseModelBillingPeriod,
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
    ExtendedSubscriptionResponseModelCurrency,
    FeedbackItem,
    FineTuningResponse,
    FineTuningResponseModelStateValue,
    Gender,
    GenerationConfig,
    GetAgentEmbedResponseModel,
    GetAgentLinkResponseModel,
    GetAgentResponseModel,
    GetAgentsPageResponseModel,
    GetAudioNativeProjectSettingsResponseModel,
    GetChaptersResponse,
    GetConvAiSettingsResponseModel,
    GetConversationResponseModel,
    GetConversationResponseModelStatus,
    GetConversationsPageResponseModel,
    GetKnowledgeBaseDependentAgentsResponseModel,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
    GetKnowledgeBaseFileResponseModel,
    GetKnowledgeBaseListResponseModel,
    GetKnowledgeBaseListResponseModelDocumentsItem,
    GetKnowledgeBaseListResponseModelDocumentsItem_File,
    GetKnowledgeBaseListResponseModelDocumentsItem_Url,
    GetKnowledgeBaseSummaryFileResponseModel,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseSummaryUrlResponseModel,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseUrlResponseModel,
    GetLibraryVoicesResponse,
    GetPhoneNumberResponseModel,
    GetProjectsResponse,
    GetPronunciationDictionariesMetadataResponseModel,
    GetPronunciationDictionaryMetadataResponse,
    GetSpeechHistoryResponse,
    GetVoicesResponse,
    GetVoicesV2ResponseModel,
    GetWorkspaceSecretsResponseModel,
    HistoryAlignmentResponseModel,
    HistoryAlignmentsResponseModel,
    HistoryItem,
    HttpValidationError,
    ImageAvatar,
    InitializeConnection,
    Invoice,
    KnowledgeBaseDocumentChunkResponseModel,
    KnowledgeBaseDocumentMetadataResponseModel,
    KnowledgeBaseLocator,
    KnowledgeBaseLocatorType,
    LanguageAddedResponse,
    LanguagePresetInput,
    LanguagePresetOutput,
    LanguagePresetTranslation,
    LanguageResponse,
    LibraryVoiceResponse,
    LibraryVoiceResponseModelCategory,
    LiteralJsonSchemaProperty,
    LiteralJsonSchemaPropertyConstantValue,
    LiteralJsonSchemaPropertyType,
    Llm,
    ManualVerificationFileResponse,
    ManualVerificationResponse,
    MetricRecord,
    Model,
    ModelRatesResponseModel,
    ModelResponseModelConcurrencyGroup,
    ModerationStatusResponseModel,
    ModerationStatusResponseModelSafetyStatus,
    ModerationStatusResponseModelWarningStatus,
    NormalizedAlignment,
    ObjectJsonSchemaPropertyInput,
    ObjectJsonSchemaPropertyInputPropertiesValue,
    ObjectJsonSchemaPropertyOutput,
    ObjectJsonSchemaPropertyOutputPropertiesValue,
    OrbAvatar,
    OutputFormat,
    PhoneNumberAgentInfo,
    PodcastBulletinMode,
    PodcastBulletinModeData,
    PodcastConversationMode,
    PodcastConversationModeData,
    PodcastProjectResponseModel,
    PodcastTextSource,
    PodcastUrlSource,
    PostAgentAvatarResponseModel,
    PostWorkspaceSecretResponseModel,
    PrivacyConfig,
    ProfilePageResponseModel,
    ProjectCreationMetaResponseModel,
    ProjectCreationMetaResponseModelStatus,
    ProjectCreationMetaResponseModelType,
    ProjectExtendedResponseModel,
    ProjectExtendedResponseModelAccessLevel,
    ProjectExtendedResponseModelApplyTextNormalization,
    ProjectExtendedResponseModelFiction,
    ProjectExtendedResponseModelQualityPreset,
    ProjectExtendedResponseModelSourceType,
    ProjectExtendedResponseModelTargetAudience,
    ProjectResponse,
    ProjectResponseModelAccessLevel,
    ProjectResponseModelFiction,
    ProjectResponseModelSourceType,
    ProjectResponseModelTargetAudience,
    ProjectSnapshotExtendedResponseModel,
    ProjectSnapshotResponse,
    ProjectSnapshotsResponse,
    ProjectState,
    PromptAgentInput,
    PromptAgentInputToolsItem,
    PromptAgentInputToolsItem_Client,
    PromptAgentInputToolsItem_System,
    PromptAgentInputToolsItem_Webhook,
    PromptAgentOutput,
    PromptAgentOutputToolsItem,
    PromptAgentOutputToolsItem_Client,
    PromptAgentOutputToolsItem_System,
    PromptAgentOutputToolsItem_Webhook,
    PromptAgentOverride,
    PromptAgentOverrideConfig,
    PromptEvaluationCriteria,
    PronunciationDictionaryAliasRuleRequestModel,
    PronunciationDictionaryPhonemeRuleRequestModel,
    PronunciationDictionaryVersionLocator,
    PronunciationDictionaryVersionResponseModel,
    PydanticPronunciationDictionaryVersionLocator,
    QueryParamsJsonSchema,
    RagChunkMetadata,
    RagConfig,
    RagIndexResponseModel,
    RagIndexStatus,
    RagRetrievalInfo,
    ReaderResourceResponseModel,
    ReaderResourceResponseModelResourceType,
    RealtimeVoiceSettings,
    RecordingResponse,
    RemovePronunciationDictionaryRulesResponseModel,
    ResourceAccessInfo,
    ResourceAccessInfoRole,
    ResourceMetadataResponseModel,
    ReviewStatus,
    SafetyCommonModel,
    SafetyEvaluation,
    SafetyResponseModel,
    SafetyRule,
    SecretDependencyType,
    SegmentCreateResponse,
    SegmentDeleteResponse,
    SegmentDubResponse,
    SegmentTranscriptionResponse,
    SegmentTranslationResponse,
    SegmentUpdateResponse,
    SendText,
    ShareOptionResponseModel,
    ShareOptionResponseModelType,
    SipTrunkCredentials,
    SpeakerResponseModel,
    SpeakerSegment,
    SpeakerSeparationResponseModel,
    SpeakerSeparationResponseModelStatus,
    SpeakerTrack,
    SpeechHistoryItemResponse,
    SpeechHistoryItemResponseModelSource,
    SpeechHistoryItemResponseModelVoiceCategory,
    SpeechToTextCharacterResponseModel,
    SpeechToTextChunkResponseModel,
    SpeechToTextWordResponseModel,
    SpeechToTextWordResponseModelType,
    StreamingAudioChunkWithTimestampsResponseModel,
    Subscription,
    SubscriptionResponse,
    SubscriptionResponseModelBillingPeriod,
    SubscriptionResponseModelCharacterRefreshPeriod,
    SubscriptionResponseModelCurrency,
    SubscriptionStatus,
    SubscriptionUsageResponseModel,
    SystemToolConfig,
    TelephonyProvider,
    TextToSpeechAsStreamRequest,
    TtsConversationalConfig,
    TtsConversationalConfigOverride,
    TtsConversationalConfigOverrideConfig,
    TtsConversationalModel,
    TtsOptimizeStreamingLatency,
    TtsOutputFormat,
    TurnConfig,
    TurnMode,
    TwilioOutboundCallResponse,
    UpdateWorkspaceMemberResponseModel,
    UrlAvatar,
    UsageCharactersResponseModel,
    User,
    UserFeedback,
    UserFeedbackScore,
    UtteranceResponseModel,
    ValidationError,
    ValidationErrorLocItem,
    VerificationAttemptResponse,
    VerifiedVoiceLanguageResponseModel,
    Voice,
    VoiceGenerationParameterOptionResponse,
    VoiceGenerationParameterResponse,
    VoicePreviewResponseModel,
    VoicePreviewsResponseModel,
    VoiceResponseModelCategory,
    VoiceResponseModelSafetyControl,
    VoiceSample,
    VoiceSettings,
    VoiceSharingModerationCheckResponseModel,
    VoiceSharingResponse,
    VoiceSharingResponseModelCategory,
    VoiceSharingState,
    VoiceVerificationResponse,
    WebhookToolApiSchemaConfigInput,
    WebhookToolApiSchemaConfigInputMethod,
    WebhookToolApiSchemaConfigInputRequestHeadersValue,
    WebhookToolApiSchemaConfigOutput,
    WebhookToolApiSchemaConfigOutputMethod,
    WebhookToolApiSchemaConfigOutputRequestHeadersValue,
    WebhookToolConfigInput,
    WebhookToolConfigOutput,
    WidgetConfig,
    WidgetConfigAvatar,
    WidgetConfigAvatar_Image,
    WidgetConfigAvatar_Orb,
    WidgetConfigAvatar_Url,
    WidgetConfigResponseModel,
    WidgetConfigResponseModelAvatar,
    WidgetConfigResponseModelAvatar_Image,
    WidgetConfigResponseModelAvatar_Orb,
    WidgetConfigResponseModelAvatar_Url,
    WidgetExpandable,
    WidgetFeedbackMode,
    WorkspaceGroupByNameResponseModel,
    WorkspaceResourceType,
)
from .errors import BadRequestError, ForbiddenError, NotFoundError, TooEarlyError, UnprocessableEntityError
from . import (
    audio_isolation,
    audio_native,
    conversational_ai,
    dubbing,
    history,
    models,
    projects,
    pronunciation_dictionary,
    samples,
    speech_to_speech,
    speech_to_text,
    studio,
    text_to_sound_effects,
    text_to_speech,
    text_to_voice,
    usage,
    user,
    v_1_text_to_speech_stream_input,
    voice_generation,
    voices,
    workspace,
)
from .client import AsyncElevenLabs, ElevenLabs
from .conversational_ai import (
    ConversationalAiCreatePhoneNumberRequestBody,
    ConversationalAiGetKnowledgeBaseDocumentByIdResponse,
    ConversationalAiGetKnowledgeBaseDocumentByIdResponse_File,
    ConversationalAiGetKnowledgeBaseDocumentByIdResponse_Url,
)
from .dubbing import DubbingGetTranscriptForDubRequestFormatType
from .environment import ElevenLabsEnvironment
from .history import HistoryGetAllRequestSource
from .play import play, save, stream
from .projects import (
    AddProjectV1ProjectsAddPostRequestApplyTextNormalization,
    AddProjectV1ProjectsAddPostRequestFiction,
    AddProjectV1ProjectsAddPostRequestSourceType,
    AddProjectV1ProjectsAddPostRequestTargetAudience,
    BodyCreatePodcastV1ProjectsPodcastCreatePostDurationScale,
    BodyCreatePodcastV1ProjectsPodcastCreatePostMode,
    BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Bulletin,
    BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Conversation,
    BodyCreatePodcastV1ProjectsPodcastCreatePostQualityPreset,
    BodyCreatePodcastV1ProjectsPodcastCreatePostSource,
    BodyCreatePodcastV1ProjectsPodcastCreatePostSourceItem,
    BodyCreatePodcastV1ProjectsPodcastCreatePostSourceItem_Text,
    BodyCreatePodcastV1ProjectsPodcastCreatePostSourceItem_Url,
)
from .pronunciation_dictionary import (
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess,
    PronunciationDictionaryAddFromFileRequestWorkspaceAccess,
    PronunciationDictionaryGetAllRequestSort,
    PronunciationDictionaryRule,
    PronunciationDictionaryRule_Alias,
    PronunciationDictionaryRule_Phoneme,
)
from .speech_to_text import SpeechToTextConvertRequestTimestampsGranularity
from .studio import (
    BodyCreatePodcastV1StudioPodcastsPostDurationScale,
    BodyCreatePodcastV1StudioPodcastsPostMode,
    BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin,
    BodyCreatePodcastV1StudioPodcastsPostMode_Conversation,
    BodyCreatePodcastV1StudioPodcastsPostQualityPreset,
    BodyCreatePodcastV1StudioPodcastsPostSource,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url,
)
from .text_to_sound_effects import TextToSoundEffectsConvertRequestOutputFormat
from .text_to_speech import (
    BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization,
    BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization,
    BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization,
    BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization,
)
from .text_to_voice import TextToVoiceCreatePreviewsRequestOutputFormat
from .v_1_text_to_speech_stream_input import SendMessage
from .version import __version__
from .voices import VoicesGetSharedRequestCategory
from .workspace import (
    BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
    BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole,
)

__all__ = [
    "Accent",
    "AddAgentSecretResponseModel",
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectResponseModel",
    "AddProjectV1ProjectsAddPostRequestApplyTextNormalization",
    "AddProjectV1ProjectsAddPostRequestFiction",
    "AddProjectV1ProjectsAddPostRequestSourceType",
    "AddProjectV1ProjectsAddPostRequestTargetAudience",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryRulesResponseModel",
    "AddSharingVoiceRequest",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "AddWorkspaceGroupMemberResponseModel",
    "AddWorkspaceInviteResponseModel",
    "Age",
    "AgentBan",
    "AgentCallLimits",
    "AgentConfigApiModelInput",
    "AgentConfigApiModelOutput",
    "AgentConfigOverride",
    "AgentConfigOverrideConfig",
    "AgentMetadataResponseModel",
    "AgentPlatformSettingsRequestModel",
    "AgentPlatformSettingsResponseModel",
    "AgentSummaryResponseModel",
    "AgentWorkspaceOverridesInput",
    "AgentWorkspaceOverridesOutput",
    "AllowlistItem",
    "ArrayJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInputItems",
    "ArrayJsonSchemaPropertyOutput",
    "ArrayJsonSchemaPropertyOutputItems",
    "AsrConversationalConfig",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AsyncElevenLabs",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeEditContentResponseModel",
    "AudioNativeProjectSettingsResponseModel",
    "AudioOutput",
    "AudioWithTimestampsResponseModel",
    "AuthSettings",
    "AuthorizationMethod",
    "BadRequestError",
    "BanReasonType",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess",
    "BodyAddToKnowledgeBaseV1ConvaiAddToKnowledgeBasePost",
    "BodyAddToKnowledgeBaseV1ConvaiAgentsAgentIdAddToKnowledgeBasePost",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostDurationScale",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostMode",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Bulletin",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Conversation",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostQualityPreset",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostSource",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostSourceItem",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostSourceItem_Text",
    "BodyCreatePodcastV1ProjectsPodcastCreatePostSourceItem_Url",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale",
    "BodyCreatePodcastV1StudioPodcastsPostMode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation",
    "BodyCreatePodcastV1StudioPodcastsPostQualityPreset",
    "BodyCreatePodcastV1StudioPodcastsPostSource",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url",
    "BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole",
    "BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization",
    "BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization",
    "BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization",
    "BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization",
    "BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole",
    "BreakdownTypes",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotExtendedResponseModel",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "CharacterAlignmentModel",
    "CharacterAlignmentResponseModel",
    "ClientEvent",
    "ClientToolConfigInput",
    "ClientToolConfigOutput",
    "CloseConnection",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretDependencies",
    "ConvAiStoredSecretDependenciesAgentToolsItem",
    "ConvAiStoredSecretDependenciesAgentToolsItem_Available",
    "ConvAiStoredSecretDependenciesAgentToolsItem_Unknown",
    "ConvAiStoredSecretDependenciesToolsItem",
    "ConvAiStoredSecretDependenciesToolsItem_Available",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown",
    "ConvAiWebhooks",
    "ConvAiWorkspaceStoredSecretConfig",
    "ConversationChargingCommonModel",
    "ConversationConfig",
    "ConversationConfigClientOverrideConfigInput",
    "ConversationConfigClientOverrideConfigOutput",
    "ConversationConfigClientOverrideInput",
    "ConversationConfigClientOverrideOutput",
    "ConversationDeletionSettings",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryMetadataCommonModelPhoneCall",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio",
    "ConversationHistoryTranscriptCommonModel",
    "ConversationHistoryTranscriptCommonModelRole",
    "ConversationHistoryTranscriptToolCallCommonModel",
    "ConversationHistoryTranscriptToolResultCommonModel",
    "ConversationHistoryTwilioPhoneCallModel",
    "ConversationHistoryTwilioPhoneCallModelDirection",
    "ConversationInitiationClientDataConfigInput",
    "ConversationInitiationClientDataConfigOutput",
    "ConversationInitiationClientDataRequestInput",
    "ConversationInitiationClientDataRequestInputDynamicVariablesValue",
    "ConversationInitiationClientDataRequestOutput",
    "ConversationInitiationClientDataRequestOutputDynamicVariablesValue",
    "ConversationInitiationClientDataWebhook",
    "ConversationInitiationClientDataWebhookRequestHeadersValue",
    "ConversationSignedUrlResponseModel",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelStatus",
    "ConversationTokenDbModel",
    "ConversationTokenPurpose",
    "ConversationTurnMetrics",
    "ConversationalAiCreatePhoneNumberRequestBody",
    "ConversationalAiGetKnowledgeBaseDocumentByIdResponse",
    "ConversationalAiGetKnowledgeBaseDocumentByIdResponse_File",
    "ConversationalAiGetKnowledgeBaseDocumentByIdResponse_Url",
    "ConversationalConfigApiModelInput",
    "ConversationalConfigApiModelOutput",
    "ConvertChapterResponseModel",
    "ConvertProjectResponseModel",
    "CreateAgentResponseModel",
    "CreateAudioNativeProjectRequest",
    "CreatePhoneNumberResponseModel",
    "CreatePronunciationDictionaryResponseModel",
    "CreateSipTrunkPhoneNumberRequest",
    "CreateTwilioPhoneNumberRequest",
    "Currency",
    "CustomLlm",
    "DataCollectionResultCommonModel",
    "DeleteChapterResponseModel",
    "DeleteDubbingResponseModel",
    "DeleteHistoryItemResponse",
    "DeleteProjectResponseModel",
    "DeleteSampleResponseModel",
    "DeleteVoiceResponseModel",
    "DeleteWorkspaceGroupMemberResponseModel",
    "DeleteWorkspaceInviteResponseModel",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentAvailableAgentToolIdentifier",
    "DependentAvailableAgentToolIdentifierAccessLevel",
    "DependentAvailableToolIdentifier",
    "DependentAvailableToolIdentifierAccessLevel",
    "DependentPhoneNumberIdentifier",
    "DependentUnknownAgentIdentifier",
    "DependentUnknownAgentToolIdentifier",
    "DependentUnknownToolIdentifier",
    "DoDubbingResponse",
    "DocumentUsageModeEnum",
    "DubbedSegment",
    "DubbingGetTranscriptForDubRequestFormatType",
    "DubbingMediaMetadata",
    "DubbingMediaReference",
    "DubbingMetadataResponse",
    "DubbingResource",
    "DynamicVariablesConfig",
    "DynamicVariablesConfigDynamicVariablePlaceholdersValue",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EditVoiceResponseModel",
    "EditVoiceSettingsResponseModel",
    "ElevenLabs",
    "ElevenLabsEnvironment",
    "EmbedVariant",
    "EmbeddingModelEnum",
    "EvaluationSettings",
    "EvaluationSuccessResult",
    "ExtendedSubscriptionResponseModelBillingPeriod",
    "ExtendedSubscriptionResponseModelCharacterRefreshPeriod",
    "ExtendedSubscriptionResponseModelCurrency",
    "FeedbackItem",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "ForbiddenError",
    "Gender",
    "GenerationConfig",
    "GetAgentEmbedResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentsPageResponseModel",
    "GetAudioNativeProjectSettingsResponseModel",
    "GetChaptersResponse",
    "GetConvAiSettingsResponseModel",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseFileResponseModel",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseListResponseModelDocumentsItem",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url",
    "GetKnowledgeBaseSummaryFileResponseModel",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryUrlResponseModel",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseUrlResponseModel",
    "GetLibraryVoicesResponse",
    "GetPhoneNumberResponseModel",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionaryMetadataResponse",
    "GetSpeechHistoryResponse",
    "GetVoicesResponse",
    "GetVoicesV2ResponseModel",
    "GetWorkspaceSecretsResponseModel",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryGetAllRequestSource",
    "HistoryItem",
    "HttpValidationError",
    "ImageAvatar",
    "InitializeConnection",
    "Invoice",
    "KnowledgeBaseDocumentChunkResponseModel",
    "KnowledgeBaseDocumentMetadataResponseModel",
    "KnowledgeBaseLocator",
    "KnowledgeBaseLocatorType",
    "LanguageAddedResponse",
    "LanguagePresetInput",
    "LanguagePresetOutput",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyConstantValue",
    "LiteralJsonSchemaPropertyType",
    "Llm",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "MetricRecord",
    "Model",
    "ModelRatesResponseModel",
    "ModelResponseModelConcurrencyGroup",
    "ModerationStatusResponseModel",
    "ModerationStatusResponseModelSafetyStatus",
    "ModerationStatusResponseModelWarningStatus",
    "NormalizedAlignment",
    "NotFoundError",
    "ObjectJsonSchemaPropertyInput",
    "ObjectJsonSchemaPropertyInputPropertiesValue",
    "ObjectJsonSchemaPropertyOutput",
    "ObjectJsonSchemaPropertyOutputPropertiesValue",
    "OrbAvatar",
    "OutputFormat",
    "PhoneNumberAgentInfo",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PostAgentAvatarResponseModel",
    "PostWorkspaceSecretResponseModel",
    "PrivacyConfig",
    "ProfilePageResponseModel",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponseModel",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelQualityPreset",
    "ProjectExtendedResponseModelSourceType",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelFiction",
    "ProjectResponseModelSourceType",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotExtendedResponseModel",
    "ProjectSnapshotResponse",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "PromptAgentInput",
    "PromptAgentInputToolsItem",
    "PromptAgentInputToolsItem_Client",
    "PromptAgentInputToolsItem_System",
    "PromptAgentInputToolsItem_Webhook",
    "PromptAgentOutput",
    "PromptAgentOutputToolsItem",
    "PromptAgentOutputToolsItem_Client",
    "PromptAgentOutputToolsItem_System",
    "PromptAgentOutputToolsItem_Webhook",
    "PromptAgentOverride",
    "PromptAgentOverrideConfig",
    "PromptEvaluationCriteria",
    "PronunciationDictionaryAddFromFileRequestWorkspaceAccess",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryGetAllRequestSort",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryRule",
    "PronunciationDictionaryRule_Alias",
    "PronunciationDictionaryRule_Phoneme",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PydanticPronunciationDictionaryVersionLocator",
    "QueryParamsJsonSchema",
    "RagChunkMetadata",
    "RagConfig",
    "RagIndexResponseModel",
    "RagIndexStatus",
    "RagRetrievalInfo",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RealtimeVoiceSettings",
    "RecordingResponse",
    "RemovePronunciationDictionaryRulesResponseModel",
    "ResourceAccessInfo",
    "ResourceAccessInfoRole",
    "ResourceMetadataResponseModel",
    "ReviewStatus",
    "SafetyCommonModel",
    "SafetyEvaluation",
    "SafetyResponseModel",
    "SafetyRule",
    "SecretDependencyType",
    "SegmentCreateResponse",
    "SegmentDeleteResponse",
    "SegmentDubResponse",
    "SegmentTranscriptionResponse",
    "SegmentTranslationResponse",
    "SegmentUpdateResponse",
    "SendMessage",
    "SendText",
    "ShareOptionResponseModel",
    "ShareOptionResponseModelType",
    "SipTrunkCredentials",
    "SpeakerResponseModel",
    "SpeakerSegment",
    "SpeakerSeparationResponseModel",
    "SpeakerSeparationResponseModelStatus",
    "SpeakerTrack",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToTextCharacterResponseModel",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextConvertRequestTimestampsGranularity",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "StreamingAudioChunkWithTimestampsResponseModel",
    "Subscription",
    "SubscriptionResponse",
    "SubscriptionResponseModelBillingPeriod",
    "SubscriptionResponseModelCharacterRefreshPeriod",
    "SubscriptionResponseModelCurrency",
    "SubscriptionStatus",
    "SubscriptionUsageResponseModel",
    "SystemToolConfig",
    "TelephonyProvider",
    "TextToSoundEffectsConvertRequestOutputFormat",
    "TextToSpeechAsStreamRequest",
    "TextToVoiceCreatePreviewsRequestOutputFormat",
    "TooEarlyError",
    "TtsConversationalConfig",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalModel",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnMode",
    "TwilioOutboundCallResponse",
    "UnprocessableEntityError",
    "UpdateWorkspaceMemberResponseModel",
    "UrlAvatar",
    "UsageCharactersResponseModel",
    "User",
    "UserFeedback",
    "UserFeedbackScore",
    "UtteranceResponseModel",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerificationAttemptResponse",
    "VerifiedVoiceLanguageResponseModel",
    "Voice",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoicePreviewResponseModel",
    "VoicePreviewsResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceVerificationResponse",
    "VoicesGetSharedRequestCategory",
    "WebhookToolApiSchemaConfigInput",
    "WebhookToolApiSchemaConfigInputMethod",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue",
    "WebhookToolApiSchemaConfigOutput",
    "WebhookToolApiSchemaConfigOutputMethod",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue",
    "WebhookToolConfigInput",
    "WebhookToolConfigOutput",
    "WidgetConfig",
    "WidgetConfigAvatar",
    "WidgetConfigAvatar_Image",
    "WidgetConfigAvatar_Orb",
    "WidgetConfigAvatar_Url",
    "WidgetConfigResponseModel",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetExpandable",
    "WidgetFeedbackMode",
    "WorkspaceGroupByNameResponseModel",
    "WorkspaceResourceType",
    "__version__",
    "audio_isolation",
    "audio_native",
    "conversational_ai",
    "dubbing",
    "history",
    "models",
    "play",
    "projects",
    "pronunciation_dictionary",
    "samples",
    "save",
    "speech_to_speech",
    "speech_to_text",
    "stream",
    "studio",
    "text_to_sound_effects",
    "text_to_speech",
    "text_to_voice",
    "usage",
    "user",
    "v_1_text_to_speech_stream_input",
    "voice_generation",
    "voices",
    "workspace",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .telephony_provider import TelephonyProvider
from .sip_trunk_credentials import SipTrunkCredentials
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CreateSipTrunkPhoneNumberRequest(UncheckedBaseModel):
    """
    SIP trunk phone number request

    Includes termination URI and optional digest authentication credentials.
    If credentials are provided, both username and password must be included.
    If credentials are not provided, ACL authentication is assumed. (user needs to add our ips in their settings)
    """

    phone_number: str = pydantic.Field()
    """
    Phone number
    """

    provider: typing.Optional[TelephonyProvider] = None
    label: str = pydantic.Field()
    """
    Label for the phone number
    """

    termination_uri: str = pydantic.Field()
    """
    SIP trunk termination URI
    """

    credentials: typing.Optional[SipTrunkCredentials] = pydantic.Field(default=None)
    """
    Optional digest authentication credentials (username/password). If not provided, ACL authentication is assumed.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

FineTuningResponseModelStateValue = typing.Union[
    typing.Literal["not_started", "queued", "fine_tuning", "fine_tuned", "failed", "delayed"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .embedding_model_enum import EmbeddingModelEnum
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class RagConfig(UncheckedBaseModel):
    enabled: typing.Optional[bool] = None
    embedding_model: typing.Optional[EmbeddingModelEnum] = None
    max_vector_distance: typing.Optional[float] = pydantic.Field(default=None)
    """
    Maximum vector distance of retrieved chunks.
    """

    max_documents_length: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum total length of document chunks retrieved from RAG.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .text_to_voice_create_previews_request_output_format import TextToVoiceCreatePreviewsRequestOutputFormat

__all__ = ["TextToVoiceCreatePreviewsRequestOutputFormat"]



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .types.text_to_sound_effects_convert_request_output_format import (
    TextToSoundEffectsConvertRequestOutputFormat,
)
from ..core.request_options import RequestOptions
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..core.unchecked_base_model import construct_type
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TextToSoundEffectsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def convert(
        self,
        *,
        text: str,
        output_format: typing.Optional[TextToSoundEffectsConvertRequestOutputFormat] = None,
        duration_seconds: typing.Optional[float] = OMIT,
        prompt_influence: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Turn text into sound effects for your videos, voice-overs or video games using the most advanced sound effects model in the world.

        Parameters
        ----------
        text : str
            The text that will get converted into a sound effect.

        output_format : typing.Optional[TextToSoundEffectsConvertRequestOutputFormat]
            Output format of the generated audio. Formatted as codec_sample_rate_bitrate. So an mp3 with 22.05kHz sample rate at 32kbs is represented as mp3_22050_32. MP3 with 192kbps bitrate requires you to be subscribed to Creator tier or above. PCM with 44.1kHz sample rate requires you to be subscribed to Pro tier or above. Note that the μ-law format (sometimes written mu-law, often approximated as u-law) is commonly used for Twilio audio inputs.

        duration_seconds : typing.Optional[float]
            The duration of the sound which will be generated in seconds. Must be at least 0.5 and at most 22. If set to None we will guess the optimal duration using the prompt. Defaults to None.

        prompt_influence : typing.Optional[float]
            A higher prompt influence makes your generation follow the prompt more closely while also making generations less variable. Must be a value between 0 and 1. Defaults to 0.3.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Yields
        ------
        typing.Iterator[bytes]
            The generated sound effect as an MP3 file

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.text_to_sound_effects.convert(
            text="Spacious braam suitable for high-impact movie trailer moments",
        )
        """
        with self._client_wrapper.httpx_client.stream(
            "v1/sound-generation",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            params={
                "output_format": output_format,
            },
            json={
                "text": text,
                "duration_seconds": duration_seconds,
                "prompt_influence": prompt_influence,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:
            try:
                if 200 <= _response.status_code < 300:
                    _chunk_size = request_options.get("chunk_size", 1024) if request_options is not None else 1024
                    for _chunk in _response.iter_bytes(chunk_size=_chunk_size):
                        yield _chunk
                    return
                _response.read()
                if _response.status_code == 422:
                    raise UnprocessableEntityError(
                        typing.cast(
                            HttpValidationError,
                            construct_type(
                                type_=HttpValidationError,  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncTextToSoundEffectsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def convert(
        self,
        *,
        text: str,
        output_format: typing.Optional[TextToSoundEffectsConvertRequestOutputFormat] = None,
        duration_seconds: typing.Optional[float] = OMIT,
        prompt_influence: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Turn text into sound effects for your videos, voice-overs or video games using the most advanced sound effects model in the world.

        Parameters
        ----------
        text : str
            The text that will get converted into a sound effect.

        output_format : typing.Optional[TextToSoundEffectsConvertRequestOutputFormat]
            Output format of the generated audio. Formatted as codec_sample_rate_bitrate. So an mp3 with 22.05kHz sample rate at 32kbs is represented as mp3_22050_32. MP3 with 192kbps bitrate requires you to be subscribed to Creator tier or above. PCM with 44.1kHz sample rate requires you to be subscribed to Pro tier or above. Note that the μ-law format (sometimes written mu-law, often approximated as u-law) is commonly used for Twilio audio inputs.

        duration_seconds : typing.Optional[float]
            The duration of the sound which will be generated in seconds. Must be at least 0.5 and at most 22. If set to None we will guess the optimal duration using the prompt. Defaults to None.

        prompt_influence : typing.Optional[float]
            A higher prompt influence makes your generation follow the prompt more closely while also making generations less variable. Must be a value between 0 and 1. Defaults to 0.3.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Yields
        ------
        typing.AsyncIterator[bytes]
            The generated sound effect as an MP3 file

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.text_to_sound_effects.convert(
                text="Spacious braam suitable for high-impact movie trailer moments",
            )


        asyncio.run(main())
        """
        async with self._client_wrapper.httpx_client.stream(
            "v1/sound-generation",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            params={
                "output_format": output_format,
            },
            json={
                "text": text,
                "duration_seconds": duration_seconds,
                "prompt_influence": prompt_influence,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        ) as _response:
            try:
                if 200 <= _response.status_code < 300:
                    _chunk_size = request_options.get("chunk_size", 1024) if request_options is not None else 1024
                    async for _chunk in _response.aiter_bytes(chunk_size=_chunk_size):
                        yield _chunk
                    return
                await _response.aread()
                if _response.status_code == 422:
                    raise UnprocessableEntityError(
                        typing.cast(
                            HttpValidationError,
                            construct_type(
                                type_=HttpValidationError,  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .turn_mode import TurnMode
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TurnConfig(UncheckedBaseModel):
    turn_timeout: typing.Optional[float] = pydantic.Field(default=None)
    """
    Maximum wait time for the user’s reply before re-engaging the user
    """

    mode: typing.Optional[TurnMode] = pydantic.Field(default=None)
    """
    The mode of turn detection
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .manual_verification_file_response import ManualVerificationFileResponse
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ManualVerificationResponse(UncheckedBaseModel):
    extra_text: str = pydantic.Field()
    """
    The extra text of the manual verification.
    """

    request_time_unix: int = pydantic.Field()
    """
    The date of the manual verification in Unix time.
    """

    files: typing.List[ManualVerificationFileResponse] = pydantic.Field()
    """
    The files of the manual verification.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .prompt_agent_override import PromptAgentOverride
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AgentConfigOverride(UncheckedBaseModel):
    prompt: typing.Optional[PromptAgentOverride] = pydantic.Field(default=None)
    """
    The overrides for the prompt configuration
    """

    first_message: typing.Optional[str] = pydantic.Field(default=None)
    """
    If non-empty, the first message the agent will say. If empty, the agent waits for the user to start the discussion
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    The language of the agent, used for ASR and TTS
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from ...types.podcast_conversation_mode_data import PodcastConversationModeData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...types.podcast_bulletin_mode_data import PodcastBulletinModeData
import typing_extensions
from ...core.unchecked_base_model import UnionMetadata


class BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Conversation(UncheckedBaseModel):
    """
    The type of podcast to generate. Can be 'conversation', an interaction between two voices, or 'bulletin', a monologue.
    """

    type: typing.Literal["conversation"] = "conversation"
    conversation: PodcastConversationModeData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Bulletin(UncheckedBaseModel):
    """
    The type of podcast to generate. Can be 'conversation', an interaction between two voices, or 'bulletin', a monologue.
    """

    type: typing.Literal["bulletin"] = "bulletin"
    bulletin: PodcastBulletinModeData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


BodyCreatePodcastV1ProjectsPodcastCreatePostMode = typing_extensions.Annotated[
    typing.Union[
        BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Conversation,
        BodyCreatePodcastV1ProjectsPodcastCreatePostMode_Bulletin,
    ],
    UnionMetadata(discriminant="type"),
]



# This file was auto-generated by Fern from our API Definition.

import typing

ClientEvent = typing.Union[
    typing.Literal[
        "conversation_initiation_metadata",
        "asr_initiation_metadata",
        "ping",
        "audio",
        "interruption",
        "user_transcript",
        "agent_response",
        "agent_response_correction",
        "client_tool_call",
        "internal_vad_score",
        "internal_turn_probability",
        "internal_tentative_agent_response",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_input import ArrayJsonSchemaPropertyInput
from .object_json_schema_property_input import ObjectJsonSchemaPropertyInput
import typing
import pydantic
from .dynamic_variables_config import DynamicVariablesConfig
from .prompt_agent_input import PromptAgentInput
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AgentConfigApiModelInput(UncheckedBaseModel):
    first_message: typing.Optional[str] = pydantic.Field(default=None)
    """
    If non-empty, the first message the agent will say. If empty, the agent waits for the user to start the discussion.
    """

    language: typing.Optional[str] = pydantic.Field(default=None)
    """
    Language of the agent - used for ASR and TTS
    """

    dynamic_variables: typing.Optional[DynamicVariablesConfig] = pydantic.Field(default=None)
    """
    Configuration for dynamic variables
    """

    prompt: typing.Optional[PromptAgentInput] = pydantic.Field(default=None)
    """
    The prompt for the agent
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .body_create_podcast_v_1_studio_podcasts_post_duration_scale import (
    BodyCreatePodcastV1StudioPodcastsPostDurationScale,
)
from .body_create_podcast_v_1_studio_podcasts_post_mode import (
    BodyCreatePodcastV1StudioPodcastsPostMode,
    BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin,
    BodyCreatePodcastV1StudioPodcastsPostMode_Conversation,
)
from .body_create_podcast_v_1_studio_podcasts_post_quality_preset import (
    BodyCreatePodcastV1StudioPodcastsPostQualityPreset,
)
from .body_create_podcast_v_1_studio_podcasts_post_source import BodyCreatePodcastV1StudioPodcastsPostSource
from .body_create_podcast_v_1_studio_podcasts_post_source_item import (
    BodyCreatePodcastV1StudioPodcastsPostSourceItem,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url,
)

__all__ = [
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale",
    "BodyCreatePodcastV1StudioPodcastsPostMode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation",
    "BodyCreatePodcastV1StudioPodcastsPostQualityPreset",
    "BodyCreatePodcastV1StudioPodcastsPostSource",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput
import typing
from .asr_conversational_config import AsrConversationalConfig
import pydantic
from .turn_config import TurnConfig
from .tts_conversational_config import TtsConversationalConfig
from .conversation_config import ConversationConfig
from .language_preset_output import LanguagePresetOutput
from .agent_config_api_model_output import AgentConfigApiModelOutput
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ConversationalConfigApiModelOutput(UncheckedBaseModel):
    asr: typing.Optional[AsrConversationalConfig] = pydantic.Field(default=None)
    """
    Configuration for conversational transcription
    """

    turn: typing.Optional[TurnConfig] = pydantic.Field(default=None)
    """
    Configuration for turn detection
    """

    tts: typing.Optional[TtsConversationalConfig] = pydantic.Field(default=None)
    """
    Configuration for conversational text to speech
    """

    conversation: typing.Optional[ConversationConfig] = pydantic.Field(default=None)
    """
    Configuration for conversational events
    """

    language_presets: typing.Optional[typing.Dict[str, LanguagePresetOutput]] = pydantic.Field(default=None)
    """
    Language presets for conversations
    """

    agent: typing.Optional[AgentConfigApiModelOutput] = pydantic.Field(default=None)
    """
    Agent specific configuration
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ...core.client_wrapper import SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.get_projects_response import GetProjectsResponse
from ...core.unchecked_base_model import construct_type
from ...errors.unprocessable_entity_error import UnprocessableEntityError
from ...types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ...core.api_error import ApiError
from .types.projects_add_request_target_audience import ProjectsAddRequestTargetAudience
from .types.projects_add_request_fiction import ProjectsAddRequestFiction
from .types.projects_add_request_apply_text_normalization import (
    ProjectsAddRequestApplyTextNormalization,
)
from .types.projects_add_request_source_type import ProjectsAddRequestSourceType
from ...types.add_project_response_model import AddProjectResponseModel
from ...types.project_extended_response_model import ProjectExtendedResponseModel
from ...core.jsonable_encoder import jsonable_encoder
from ...types.edit_project_response_model import EditProjectResponseModel
from ...types.delete_project_response_model import DeleteProjectResponseModel
from ...types.convert_project_response_model import ConvertProjectResponseModel
from ...types.project_snapshots_response import ProjectSnapshotsResponse
from ...types.project_snapshot_extended_response_model import (
    ProjectSnapshotExtendedResponseModel,
)
from ...types.pronunciation_dictionary_version_locator import (
    PronunciationDictionaryVersionLocator,
)
from ...types.create_pronunciation_dictionary_response_model import (
    CreatePronunciationDictionaryResponseModel,
)
from ...core.serialization import convert_and_respect_annotation_metadata
from ...core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ProjectsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_all(self, *, request_options: typing.Optional[RequestOptions] = None) -> GetProjectsResponse:
        """
        Returns a list of your Studio projects with metadata.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectsResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.get_all()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/studio/projects",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetProjectsResponse,
                    construct_type(
                        type_=GetProjectsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def add(
        self,
        *,
        name: str,
        default_title_voice_id: str,
        default_paragraph_voice_id: str,
        default_model_id: str,
        from_url: typing.Optional[str] = OMIT,
        from_document: typing.Optional[str] = OMIT,
        quality_preset: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        author: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        genres: typing.Optional[typing.List[str]] = OMIT,
        target_audience: typing.Optional[ProjectsAddRequestTargetAudience] = OMIT,
        language: typing.Optional[str] = OMIT,
        content_type: typing.Optional[str] = OMIT,
        original_publication_date: typing.Optional[str] = OMIT,
        mature_content: typing.Optional[bool] = OMIT,
        isbn_number: typing.Optional[str] = OMIT,
        acx_volume_normalization: typing.Optional[bool] = OMIT,
        volume_normalization: typing.Optional[bool] = OMIT,
        pronunciation_dictionary_locators: typing.Optional[typing.List[str]] = OMIT,
        callback_url: typing.Optional[str] = OMIT,
        fiction: typing.Optional[ProjectsAddRequestFiction] = OMIT,
        apply_text_normalization: typing.Optional[ProjectsAddRequestApplyTextNormalization] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        auto_assign_voices: typing.Optional[bool] = OMIT,
        source_type: typing.Optional[ProjectsAddRequestSourceType] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddProjectResponseModel:
        """
        Creates a new Studio project, it can be either initialized as blank, from a document or from a URL.

        Parameters
        ----------
        name : str
            The name of the Studio project, used for identification only.

        default_title_voice_id : str
            The voice_id that corresponds to the default voice used for new titles.

        default_paragraph_voice_id : str
            The voice_id that corresponds to the default voice used for new paragraphs.

        default_model_id : str
            The ID of the model to be used for this Studio project, you can query GET /v1/models to list all available models.

        from_url : typing.Optional[str]
            An optional URL from which we will extract content to initialize the Studio project. If this is set, 'from_url' must be null. If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        from_document : typing.Optional[str]
            An optional .epub, .pdf, .txt or similar file can be provided. If provided, we will initialize the Studio project with its content. If this is set, 'from_url' must be null.  If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        quality_preset : typing.Optional[str]
            Output quality of the generated audio. Must be one of:
            standard - standard output format, 128kbps with 44.1kHz sample rate.
            high - high quality output format, 192kbps with 44.1kHz sample rate and major improvements on our side. Using this setting increases the credit cost by 20%.
            ultra - ultra quality output format, 192kbps with 44.1kHz sample rate and highest improvements on our side. Using this setting increases the credit cost by 50%.
            ultra lossless - ultra quality output format, 705.6kbps with 44.1kHz sample rate and highest improvements on our side in a fully lossless format. Using this setting increases the credit cost by 100%.

        title : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        author : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        description : typing.Optional[str]
            An optional description of the Studio project.

        genres : typing.Optional[typing.List[str]]
            An optional list of genres associated with the Studio project.

        target_audience : typing.Optional[ProjectsAddRequestTargetAudience]
            An optional target audience of the Studio project.

        language : typing.Optional[str]
            An optional language of the Studio project. Two-letter language code (ISO 639-1).

        content_type : typing.Optional[str]
            An optional content type of the Studio project.

        original_publication_date : typing.Optional[str]
            An optional original publication date of the Studio project, in the format YYYY-MM-DD or YYYY.

        mature_content : typing.Optional[bool]
            An optional specification of whether this Studio project contains mature content.

        isbn_number : typing.Optional[str]
            An optional ISBN number of the Studio project you want to create, this will be added as metadata to the mp3 file on Studio project or chapter download.

        acx_volume_normalization : typing.Optional[bool]
            [Deprecated] When the Studio project is downloaded, should the returned audio have postprocessing in order to make it compliant with audiobook normalized volume requirements

        volume_normalization : typing.Optional[bool]
            When the Studio project is downloaded, should the returned audio have postprocessing in order to make it compliant with audiobook normalized volume requirements

        pronunciation_dictionary_locators : typing.Optional[typing.List[str]]
            A list of pronunciation dictionary locators (pronunciation_dictionary_id, version_id) encoded as a list of JSON strings for pronunciation dictionaries to be applied to the text. A list of json encoded strings is required as adding projects may occur through formData as opposed to jsonBody. To specify multiple dictionaries use multiple --form lines in your curl, such as --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"Vmd4Zor6fplcA7WrINey\",\"version_id\":\"hRPaxjlTdR7wFMhV4w0b\"}"' --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"JzWtcGQMJ6bnlWwyMo7e\",\"version_id\":\"lbmwxiLu4q6txYxgdZqn\"}"'. Note that multiple dictionaries are not currently supported by our UI which will only show the first.

        callback_url : typing.Optional[str]
            A url that will be called by our service when the Studio project is converted. Request will contain a json blob containing the status of the conversion

        fiction : typing.Optional[ProjectsAddRequestFiction]
            An optional specification of whether the content of this Studio project is fiction.

        apply_text_normalization : typing.Optional[ProjectsAddRequestApplyTextNormalization]

                This parameter controls text normalization with four modes: 'auto', 'on', 'apply_english' and 'off'.
                When set to 'auto', the system will automatically decide whether to apply text normalization
                (e.g., spelling out numbers). With 'on', text normalization will always be applied, while
                with 'off', it will be skipped. 'apply_english' is the same as 'on' but will assume that text is in English.


        auto_convert : typing.Optional[bool]
            Whether to auto convert the Studio project to audio or not.

        auto_assign_voices : typing.Optional[bool]
            [Alpha Feature] Whether automatically assign voices to phrases in the create Project.

        source_type : typing.Optional[ProjectsAddRequestSourceType]
            The type of Studio project to create.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddProjectResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.add(
            name="name",
            default_title_voice_id="default_title_voice_id",
            default_paragraph_voice_id="default_paragraph_voice_id",
            default_model_id="default_model_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/studio/projects",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            data={
                "name": name,
                "default_title_voice_id": default_title_voice_id,
                "default_paragraph_voice_id": default_paragraph_voice_id,
                "default_model_id": default_model_id,
                "from_url": from_url,
                "from_document": from_document,
                "quality_preset": quality_preset,
                "title": title,
                "author": author,
                "description": description,
                "genres": genres,
                "target_audience": target_audience,
                "language": language,
                "content_type": content_type,
                "original_publication_date": original_publication_date,
                "mature_content": mature_content,
                "isbn_number": isbn_number,
                "acx_volume_normalization": acx_volume_normalization,
                "volume_normalization": volume_normalization,
                "pronunciation_dictionary_locators": pronunciation_dictionary_locators,
                "callback_url": callback_url,
                "fiction": fiction,
                "apply_text_normalization": apply_text_normalization,
                "auto_convert": auto_convert,
                "auto_assign_voices": auto_assign_voices,
                "source_type": source_type,
            },
            files={},
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddProjectResponseModel,
                    construct_type(
                        type_=AddProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectExtendedResponseModel:
        """
        Returns information about a specific Studio project. This endpoint returns more detailed information about a project than `GET /v1/studio`.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectExtendedResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.get(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectExtendedResponseModel,
                    construct_type(
                        type_=ProjectExtendedResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_metadata(
        self,
        project_id: str,
        *,
        name: str,
        default_title_voice_id: str,
        default_paragraph_voice_id: str,
        title: typing.Optional[str] = OMIT,
        author: typing.Optional[str] = OMIT,
        isbn_number: typing.Optional[str] = OMIT,
        volume_normalization: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditProjectResponseModel:
        """
        Updates the specified Studio project by setting the values of the parameters passed.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        name : str
            The name of the Studio project, used for identification only.

        default_title_voice_id : str
            The voice_id that corresponds to the default voice used for new titles.

        default_paragraph_voice_id : str
            The voice_id that corresponds to the default voice used for new paragraphs.

        title : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        author : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        isbn_number : typing.Optional[str]
            An optional ISBN number of the Studio project you want to create, this will be added as metadata to the mp3 file on Studio project or chapter download.

        volume_normalization : typing.Optional[bool]
            When the Studio project is downloaded, should the returned audio have postprocessing in order to make it compliant with audiobook normalized volume requirements

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditProjectResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.update_metadata(
            project_id="21m00Tcm4TlvDq8ikWAM",
            name="Project 1",
            default_title_voice_id="21m00Tcm4TlvDq8ikWAM",
            default_paragraph_voice_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "name": name,
                "default_title_voice_id": default_title_voice_id,
                "default_paragraph_voice_id": default_paragraph_voice_id,
                "title": title,
                "author": author,
                "isbn_number": isbn_number,
                "volume_normalization": volume_normalization,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EditProjectResponseModel,
                    construct_type(
                        type_=EditProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DeleteProjectResponseModel:
        """
        Deletes a Studio project.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.delete(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteProjectResponseModel,
                    construct_type(
                        type_=DeleteProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_content(
        self,
        project_id: str,
        *,
        from_url: typing.Optional[str] = OMIT,
        from_document: typing.Optional[str] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditProjectResponseModel:
        """
        Updates Studio project content.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        from_url : typing.Optional[str]
            An optional URL from which we will extract content to initialize the Studio project. If this is set, 'from_url' must be null. If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        from_document : typing.Optional[str]
            An optional .epub, .pdf, .txt or similar file can be provided. If provided, we will initialize the Studio project with its content. If this is set, 'from_url' must be null.  If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        auto_convert : typing.Optional[bool]
            Whether to auto convert the Studio project to audio or not.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditProjectResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.update_content(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/content",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            data={
                "from_url": from_url,
                "from_document": from_document,
                "auto_convert": auto_convert,
            },
            files={},
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EditProjectResponseModel,
                    construct_type(
                        type_=EditProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def convert(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConvertProjectResponseModel:
        """
        Starts conversion of a Studio project and all of its chapters.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConvertProjectResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.convert(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/convert",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ConvertProjectResponseModel,
                    construct_type(
                        type_=ConvertProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_snapshots(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectSnapshotsResponse:
        """
        Retrieves a list of snapshots for a Studio project.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectSnapshotsResponse
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.get_snapshots(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectSnapshotsResponse,
                    construct_type(
                        type_=ProjectSnapshotsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_project_snapshot(
        self,
        project_id: str,
        project_snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectSnapshotExtendedResponseModel:
        """
        Returns the project snapshot.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        project_snapshot_id : str
            The ID of the Studio project snapshot.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectSnapshotExtendedResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.get_project_snapshot(
            project_id="21m00Tcm4TlvDq8ikWAM",
            project_snapshot_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots/{jsonable_encoder(project_snapshot_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectSnapshotExtendedResponseModel,
                    construct_type(
                        type_=ProjectSnapshotExtendedResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def stream_audio(
        self,
        project_id: str,
        project_snapshot_id: str,
        *,
        convert_to_mpeg: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Stream the audio from a Studio project snapshot.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        project_snapshot_id : str
            The ID of the Studio project snapshot.

        convert_to_mpeg : typing.Optional[bool]
            Whether to convert the audio to mpeg format.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.stream_audio(
            project_id="21m00Tcm4TlvDq8ikWAM",
            project_snapshot_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots/{jsonable_encoder(project_snapshot_id)}/stream",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "convert_to_mpeg": convert_to_mpeg,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def stream_archive(
        self,
        project_id: str,
        project_snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.Iterator[bytes]:
        """
        Returns a compressed archive of the Studio project's audio.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        project_snapshot_id : str
            The ID of the Studio project snapshot.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Yields
        ------
        typing.Iterator[bytes]
            Streaming archive data
        """
        with self._client_wrapper.httpx_client.stream(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots/{jsonable_encoder(project_snapshot_id)}/archive",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            request_options=request_options,
        ) as _response:
            try:
                if 200 <= _response.status_code < 300:
                    _chunk_size = request_options.get("chunk_size", 1024) if request_options is not None else 1024
                    for _chunk in _response.iter_bytes(chunk_size=_chunk_size):
                        yield _chunk
                    return
                _response.read()
                if _response.status_code == 422:
                    raise UnprocessableEntityError(
                        typing.cast(
                            HttpValidationError,
                            construct_type(
                                type_=HttpValidationError,  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_pronunciation_dictionaries(
        self,
        project_id: str,
        *,
        pronunciation_dictionary_locators: typing.Sequence[PronunciationDictionaryVersionLocator],
        invalidate_affected_text: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreatePronunciationDictionaryResponseModel:
        """
        Create a set of pronunciation dictionaries acting on a project. This will automatically mark text within this project as requiring reconverting where the new dictionary would apply or the old one no longer does.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        pronunciation_dictionary_locators : typing.Sequence[PronunciationDictionaryVersionLocator]
            A list of pronunciation dictionary locators (pronunciation_dictionary_id, version_id) encoded as a list of JSON strings for pronunciation dictionaries to be applied to the text. A list of json encoded strings is required as adding projects may occur through formData as opposed to jsonBody. To specify multiple dictionaries use multiple --form lines in your curl, such as --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"Vmd4Zor6fplcA7WrINey\",\"version_id\":\"hRPaxjlTdR7wFMhV4w0b\"}"' --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"JzWtcGQMJ6bnlWwyMo7e\",\"version_id\":\"lbmwxiLu4q6txYxgdZqn\"}"'. Note that multiple dictionaries are not currently supported by our UI which will only show the first.

        invalidate_affected_text : typing.Optional[bool]
            This will automatically mark text in this project for reconversion when the new dictionary applies or the old one no longer does.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreatePronunciationDictionaryResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs, PronunciationDictionaryVersionLocator

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.studio.projects.update_pronunciation_dictionaries(
            project_id="21m00Tcm4TlvDq8ikWAM",
            pronunciation_dictionary_locators=[
                PronunciationDictionaryVersionLocator(
                    pronunciation_dictionary_id="pronunciation_dictionary_id",
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/pronunciation-dictionaries",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "pronunciation_dictionary_locators": convert_and_respect_annotation_metadata(
                    object_=pronunciation_dictionary_locators,
                    annotation=typing.Sequence[PronunciationDictionaryVersionLocator],
                    direction="write",
                ),
                "invalidate_affected_text": invalidate_affected_text,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    CreatePronunciationDictionaryResponseModel,
                    construct_type(
                        type_=CreatePronunciationDictionaryResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncProjectsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_all(self, *, request_options: typing.Optional[RequestOptions] = None) -> GetProjectsResponse:
        """
        Returns a list of your Studio projects with metadata.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetProjectsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.get_all()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/studio/projects",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    GetProjectsResponse,
                    construct_type(
                        type_=GetProjectsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def add(
        self,
        *,
        name: str,
        default_title_voice_id: str,
        default_paragraph_voice_id: str,
        default_model_id: str,
        from_url: typing.Optional[str] = OMIT,
        from_document: typing.Optional[str] = OMIT,
        quality_preset: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        author: typing.Optional[str] = OMIT,
        description: typing.Optional[str] = OMIT,
        genres: typing.Optional[typing.List[str]] = OMIT,
        target_audience: typing.Optional[ProjectsAddRequestTargetAudience] = OMIT,
        language: typing.Optional[str] = OMIT,
        content_type: typing.Optional[str] = OMIT,
        original_publication_date: typing.Optional[str] = OMIT,
        mature_content: typing.Optional[bool] = OMIT,
        isbn_number: typing.Optional[str] = OMIT,
        acx_volume_normalization: typing.Optional[bool] = OMIT,
        volume_normalization: typing.Optional[bool] = OMIT,
        pronunciation_dictionary_locators: typing.Optional[typing.List[str]] = OMIT,
        callback_url: typing.Optional[str] = OMIT,
        fiction: typing.Optional[ProjectsAddRequestFiction] = OMIT,
        apply_text_normalization: typing.Optional[ProjectsAddRequestApplyTextNormalization] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        auto_assign_voices: typing.Optional[bool] = OMIT,
        source_type: typing.Optional[ProjectsAddRequestSourceType] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AddProjectResponseModel:
        """
        Creates a new Studio project, it can be either initialized as blank, from a document or from a URL.

        Parameters
        ----------
        name : str
            The name of the Studio project, used for identification only.

        default_title_voice_id : str
            The voice_id that corresponds to the default voice used for new titles.

        default_paragraph_voice_id : str
            The voice_id that corresponds to the default voice used for new paragraphs.

        default_model_id : str
            The ID of the model to be used for this Studio project, you can query GET /v1/models to list all available models.

        from_url : typing.Optional[str]
            An optional URL from which we will extract content to initialize the Studio project. If this is set, 'from_url' must be null. If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        from_document : typing.Optional[str]
            An optional .epub, .pdf, .txt or similar file can be provided. If provided, we will initialize the Studio project with its content. If this is set, 'from_url' must be null.  If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        quality_preset : typing.Optional[str]
            Output quality of the generated audio. Must be one of:
            standard - standard output format, 128kbps with 44.1kHz sample rate.
            high - high quality output format, 192kbps with 44.1kHz sample rate and major improvements on our side. Using this setting increases the credit cost by 20%.
            ultra - ultra quality output format, 192kbps with 44.1kHz sample rate and highest improvements on our side. Using this setting increases the credit cost by 50%.
            ultra lossless - ultra quality output format, 705.6kbps with 44.1kHz sample rate and highest improvements on our side in a fully lossless format. Using this setting increases the credit cost by 100%.

        title : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        author : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        description : typing.Optional[str]
            An optional description of the Studio project.

        genres : typing.Optional[typing.List[str]]
            An optional list of genres associated with the Studio project.

        target_audience : typing.Optional[ProjectsAddRequestTargetAudience]
            An optional target audience of the Studio project.

        language : typing.Optional[str]
            An optional language of the Studio project. Two-letter language code (ISO 639-1).

        content_type : typing.Optional[str]
            An optional content type of the Studio project.

        original_publication_date : typing.Optional[str]
            An optional original publication date of the Studio project, in the format YYYY-MM-DD or YYYY.

        mature_content : typing.Optional[bool]
            An optional specification of whether this Studio project contains mature content.

        isbn_number : typing.Optional[str]
            An optional ISBN number of the Studio project you want to create, this will be added as metadata to the mp3 file on Studio project or chapter download.

        acx_volume_normalization : typing.Optional[bool]
            [Deprecated] When the Studio project is downloaded, should the returned audio have postprocessing in order to make it compliant with audiobook normalized volume requirements

        volume_normalization : typing.Optional[bool]
            When the Studio project is downloaded, should the returned audio have postprocessing in order to make it compliant with audiobook normalized volume requirements

        pronunciation_dictionary_locators : typing.Optional[typing.List[str]]
            A list of pronunciation dictionary locators (pronunciation_dictionary_id, version_id) encoded as a list of JSON strings for pronunciation dictionaries to be applied to the text. A list of json encoded strings is required as adding projects may occur through formData as opposed to jsonBody. To specify multiple dictionaries use multiple --form lines in your curl, such as --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"Vmd4Zor6fplcA7WrINey\",\"version_id\":\"hRPaxjlTdR7wFMhV4w0b\"}"' --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"JzWtcGQMJ6bnlWwyMo7e\",\"version_id\":\"lbmwxiLu4q6txYxgdZqn\"}"'. Note that multiple dictionaries are not currently supported by our UI which will only show the first.

        callback_url : typing.Optional[str]
            A url that will be called by our service when the Studio project is converted. Request will contain a json blob containing the status of the conversion

        fiction : typing.Optional[ProjectsAddRequestFiction]
            An optional specification of whether the content of this Studio project is fiction.

        apply_text_normalization : typing.Optional[ProjectsAddRequestApplyTextNormalization]

                This parameter controls text normalization with four modes: 'auto', 'on', 'apply_english' and 'off'.
                When set to 'auto', the system will automatically decide whether to apply text normalization
                (e.g., spelling out numbers). With 'on', text normalization will always be applied, while
                with 'off', it will be skipped. 'apply_english' is the same as 'on' but will assume that text is in English.


        auto_convert : typing.Optional[bool]
            Whether to auto convert the Studio project to audio or not.

        auto_assign_voices : typing.Optional[bool]
            [Alpha Feature] Whether automatically assign voices to phrases in the create Project.

        source_type : typing.Optional[ProjectsAddRequestSourceType]
            The type of Studio project to create.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AddProjectResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.add(
                name="name",
                default_title_voice_id="default_title_voice_id",
                default_paragraph_voice_id="default_paragraph_voice_id",
                default_model_id="default_model_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/studio/projects",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            data={
                "name": name,
                "default_title_voice_id": default_title_voice_id,
                "default_paragraph_voice_id": default_paragraph_voice_id,
                "default_model_id": default_model_id,
                "from_url": from_url,
                "from_document": from_document,
                "quality_preset": quality_preset,
                "title": title,
                "author": author,
                "description": description,
                "genres": genres,
                "target_audience": target_audience,
                "language": language,
                "content_type": content_type,
                "original_publication_date": original_publication_date,
                "mature_content": mature_content,
                "isbn_number": isbn_number,
                "acx_volume_normalization": acx_volume_normalization,
                "volume_normalization": volume_normalization,
                "pronunciation_dictionary_locators": pronunciation_dictionary_locators,
                "callback_url": callback_url,
                "fiction": fiction,
                "apply_text_normalization": apply_text_normalization,
                "auto_convert": auto_convert,
                "auto_assign_voices": auto_assign_voices,
                "source_type": source_type,
            },
            files={},
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AddProjectResponseModel,
                    construct_type(
                        type_=AddProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectExtendedResponseModel:
        """
        Returns information about a specific Studio project. This endpoint returns more detailed information about a project than `GET /v1/studio`.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectExtendedResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.get(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectExtendedResponseModel,
                    construct_type(
                        type_=ProjectExtendedResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_metadata(
        self,
        project_id: str,
        *,
        name: str,
        default_title_voice_id: str,
        default_paragraph_voice_id: str,
        title: typing.Optional[str] = OMIT,
        author: typing.Optional[str] = OMIT,
        isbn_number: typing.Optional[str] = OMIT,
        volume_normalization: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditProjectResponseModel:
        """
        Updates the specified Studio project by setting the values of the parameters passed.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        name : str
            The name of the Studio project, used for identification only.

        default_title_voice_id : str
            The voice_id that corresponds to the default voice used for new titles.

        default_paragraph_voice_id : str
            The voice_id that corresponds to the default voice used for new paragraphs.

        title : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        author : typing.Optional[str]
            An optional name of the author of the Studio project, this will be added as metadata to the mp3 file on Studio project or chapter download.

        isbn_number : typing.Optional[str]
            An optional ISBN number of the Studio project you want to create, this will be added as metadata to the mp3 file on Studio project or chapter download.

        volume_normalization : typing.Optional[bool]
            When the Studio project is downloaded, should the returned audio have postprocessing in order to make it compliant with audiobook normalized volume requirements

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditProjectResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.update_metadata(
                project_id="21m00Tcm4TlvDq8ikWAM",
                name="Project 1",
                default_title_voice_id="21m00Tcm4TlvDq8ikWAM",
                default_paragraph_voice_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "name": name,
                "default_title_voice_id": default_title_voice_id,
                "default_paragraph_voice_id": default_paragraph_voice_id,
                "title": title,
                "author": author,
                "isbn_number": isbn_number,
                "volume_normalization": volume_normalization,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EditProjectResponseModel,
                    construct_type(
                        type_=EditProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> DeleteProjectResponseModel:
        """
        Deletes a Studio project.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteProjectResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.delete(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    DeleteProjectResponseModel,
                    construct_type(
                        type_=DeleteProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_content(
        self,
        project_id: str,
        *,
        from_url: typing.Optional[str] = OMIT,
        from_document: typing.Optional[str] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditProjectResponseModel:
        """
        Updates Studio project content.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        from_url : typing.Optional[str]
            An optional URL from which we will extract content to initialize the Studio project. If this is set, 'from_url' must be null. If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        from_document : typing.Optional[str]
            An optional .epub, .pdf, .txt or similar file can be provided. If provided, we will initialize the Studio project with its content. If this is set, 'from_url' must be null.  If neither 'from_url' or 'from_document' are provided we will initialize the Studio project as blank.

        auto_convert : typing.Optional[bool]
            Whether to auto convert the Studio project to audio or not.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditProjectResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.update_content(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/content",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            data={
                "from_url": from_url,
                "from_document": from_document,
                "auto_convert": auto_convert,
            },
            files={},
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    EditProjectResponseModel,
                    construct_type(
                        type_=EditProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def convert(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ConvertProjectResponseModel:
        """
        Starts conversion of a Studio project and all of its chapters.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ConvertProjectResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.convert(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/convert",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ConvertProjectResponseModel,
                    construct_type(
                        type_=ConvertProjectResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_snapshots(
        self,
        project_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectSnapshotsResponse:
        """
        Retrieves a list of snapshots for a Studio project.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectSnapshotsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.get_snapshots(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectSnapshotsResponse,
                    construct_type(
                        type_=ProjectSnapshotsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_project_snapshot(
        self,
        project_id: str,
        project_snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectSnapshotExtendedResponseModel:
        """
        Returns the project snapshot.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        project_snapshot_id : str
            The ID of the Studio project snapshot.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectSnapshotExtendedResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.get_project_snapshot(
                project_id="21m00Tcm4TlvDq8ikWAM",
                project_snapshot_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots/{jsonable_encoder(project_snapshot_id)}",
            base_url=self._client_wrapper.get_environment().base,
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectSnapshotExtendedResponseModel,
                    construct_type(
                        type_=ProjectSnapshotExtendedResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def stream_audio(
        self,
        project_id: str,
        project_snapshot_id: str,
        *,
        convert_to_mpeg: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Stream the audio from a Studio project snapshot.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        project_snapshot_id : str
            The ID of the Studio project snapshot.

        convert_to_mpeg : typing.Optional[bool]
            Whether to convert the audio to mpeg format.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.stream_audio(
                project_id="21m00Tcm4TlvDq8ikWAM",
                project_snapshot_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots/{jsonable_encoder(project_snapshot_id)}/stream",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "convert_to_mpeg": convert_to_mpeg,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def stream_archive(
        self,
        project_id: str,
        project_snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> typing.AsyncIterator[bytes]:
        """
        Returns a compressed archive of the Studio project's audio.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        project_snapshot_id : str
            The ID of the Studio project snapshot.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration. You can pass in configuration such as `chunk_size`, and more to customize the request and response.

        Yields
        ------
        typing.AsyncIterator[bytes]
            Streaming archive data
        """
        async with self._client_wrapper.httpx_client.stream(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/snapshots/{jsonable_encoder(project_snapshot_id)}/archive",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            request_options=request_options,
        ) as _response:
            try:
                if 200 <= _response.status_code < 300:
                    _chunk_size = request_options.get("chunk_size", 1024) if request_options is not None else 1024
                    async for _chunk in _response.aiter_bytes(chunk_size=_chunk_size):
                        yield _chunk
                    return
                await _response.aread()
                if _response.status_code == 422:
                    raise UnprocessableEntityError(
                        typing.cast(
                            HttpValidationError,
                            construct_type(
                                type_=HttpValidationError,  # type: ignore
                                object_=_response.json(),
                            ),
                        )
                    )
                _response_json = _response.json()
            except JSONDecodeError:
                raise ApiError(status_code=_response.status_code, body=_response.text)
            raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_pronunciation_dictionaries(
        self,
        project_id: str,
        *,
        pronunciation_dictionary_locators: typing.Sequence[PronunciationDictionaryVersionLocator],
        invalidate_affected_text: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreatePronunciationDictionaryResponseModel:
        """
        Create a set of pronunciation dictionaries acting on a project. This will automatically mark text within this project as requiring reconverting where the new dictionary would apply or the old one no longer does.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        pronunciation_dictionary_locators : typing.Sequence[PronunciationDictionaryVersionLocator]
            A list of pronunciation dictionary locators (pronunciation_dictionary_id, version_id) encoded as a list of JSON strings for pronunciation dictionaries to be applied to the text. A list of json encoded strings is required as adding projects may occur through formData as opposed to jsonBody. To specify multiple dictionaries use multiple --form lines in your curl, such as --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"Vmd4Zor6fplcA7WrINey\",\"version_id\":\"hRPaxjlTdR7wFMhV4w0b\"}"' --form 'pronunciation_dictionary_locators="{\"pronunciation_dictionary_id\":\"JzWtcGQMJ6bnlWwyMo7e\",\"version_id\":\"lbmwxiLu4q6txYxgdZqn\"}"'. Note that multiple dictionaries are not currently supported by our UI which will only show the first.

        invalidate_affected_text : typing.Optional[bool]
            This will automatically mark text in this project for reconversion when the new dictionary applies or the old one no longer does.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreatePronunciationDictionaryResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs, PronunciationDictionaryVersionLocator

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.studio.projects.update_pronunciation_dictionaries(
                project_id="21m00Tcm4TlvDq8ikWAM",
                pronunciation_dictionary_locators=[
                    PronunciationDictionaryVersionLocator(
                        pronunciation_dictionary_id="pronunciation_dictionary_id",
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/studio/projects/{jsonable_encoder(project_id)}/pronunciation-dictionaries",
            base_url=self._client_wrapper.get_environment().base,
            method="POST",
            json={
                "pronunciation_dictionary_locators": convert_and_respect_annotation_metadata(
                    object_=pronunciation_dictionary_locators,
                    annotation=typing.Sequence[PronunciationDictionaryVersionLocator],
                    direction="write",
                ),
                "invalidate_affected_text": invalidate_affected_text,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    CreatePronunciationDictionaryResponseModel,
                    construct_type(
                        type_=CreatePronunciationDictionaryResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

ModerationStatusResponseModelSafetyStatus = typing.Union[
    typing.Literal["appeal_approved", "appeal_denied", "false_positive"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .language_response import LanguageResponse
from .model_rates_response_model import ModelRatesResponseModel
from .model_response_model_concurrency_group import ModelResponseModelConcurrencyGroup
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class Model(UncheckedBaseModel):
    model_id: str = pydantic.Field()
    """
    The unique identifier of the model.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the model.
    """

    can_be_finetuned: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model can be finetuned.
    """

    can_do_text_to_speech: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model can do text-to-speech.
    """

    can_do_voice_conversion: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model can do voice conversion.
    """

    can_use_style: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model can use style.
    """

    can_use_speaker_boost: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model can use speaker boost.
    """

    serves_pro_voices: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model serves pro voices.
    """

    token_cost_factor: typing.Optional[float] = pydantic.Field(default=None)
    """
    The cost factor for the model.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the model.
    """

    requires_alpha_access: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the model requires alpha access.
    """

    max_characters_request_free_user: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of characters that can be requested by a free user.
    """

    max_characters_request_subscribed_user: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of characters that can be requested by a subscribed user.
    """

    maximum_text_length_per_request: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum length of text that can be requested for this model.
    """

    languages: typing.Optional[typing.List[LanguageResponse]] = pydantic.Field(default=None)
    """
    The languages supported by the model.
    """

    model_rates: typing.Optional[ModelRatesResponseModel] = pydantic.Field(default=None)
    """
    The rates for the model.
    """

    concurrency_group: typing.Optional[ModelResponseModelConcurrencyGroup] = pydantic.Field(default=None)
    """
    The concurrency group for the model.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput
from .webhook_tool_api_schema_config_output import WebhookToolApiSchemaConfigOutput
import pydantic
import typing
from .dynamic_variables_config import DynamicVariablesConfig
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class WebhookToolConfigOutput(UncheckedBaseModel):
    """
    A webhook tool is a tool that calls an external webhook from our server
    """

    name: str
    description: str
    api_schema: WebhookToolApiSchemaConfigOutput = pydantic.Field()
    """
    The schema for the outgoing webhoook, including parameters and URL specification
    """

    dynamic_variables: typing.Optional[DynamicVariablesConfig] = pydantic.Field(default=None)
    """
    Configuration for dynamic variables
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput
import typing
import pydantic
from .llm import Llm
from .prompt_agent_output_tools_item import PromptAgentOutputToolsItem
from .knowledge_base_locator import KnowledgeBaseLocator
from .custom_llm import CustomLlm
from .rag_config import RagConfig
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class PromptAgentOutput(UncheckedBaseModel):
    prompt: typing.Optional[str] = pydantic.Field(default=None)
    """
    The prompt for the agent
    """

    llm: typing.Optional[Llm] = pydantic.Field(default=None)
    """
    The LLM to query with the prompt and the chat history
    """

    temperature: typing.Optional[float] = pydantic.Field(default=None)
    """
    The temperature for the LLM
    """

    max_tokens: typing.Optional[int] = pydantic.Field(default=None)
    """
    If greater than 0, maximum number of tokens the LLM can predict
    """

    tools: typing.Optional[typing.List[PromptAgentOutputToolsItem]] = pydantic.Field(default=None)
    """
    A list of tools that the agent can use over the course of the conversation
    """

    tool_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    A list of IDs of tools used by the agent
    """

    knowledge_base: typing.Optional[typing.List[KnowledgeBaseLocator]] = pydantic.Field(default=None)
    """
    A list of knowledge bases to be used by the agent
    """

    custom_llm: typing.Optional[CustomLlm] = pydantic.Field(default=None)
    """
    Definition for a custom LLM if LLM field is set to 'CUSTOM_LLM'
    """

    ignore_default_personality: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to ignore the default personality
    """

    rag: typing.Optional[RagConfig] = pydantic.Field(default=None)
    """
    Configuration for RAG
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .conversation_deletion_settings import ConversationDeletionSettings
from .conversation_history_feedback_common_model import (
    ConversationHistoryFeedbackCommonModel,
)
from .authorization_method import AuthorizationMethod
from .conversation_charging_common_model import ConversationChargingCommonModel
from .conversation_history_metadata_common_model_phone_call import (
    ConversationHistoryMetadataCommonModelPhoneCall,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConversationHistoryMetadataCommonModel(UncheckedBaseModel):
    start_time_unix_secs: int
    call_duration_secs: int
    cost: typing.Optional[int] = None
    deletion_settings: typing.Optional[ConversationDeletionSettings] = None
    feedback: typing.Optional[ConversationHistoryFeedbackCommonModel] = None
    authorization_method: typing.Optional[AuthorizationMethod] = None
    charging: typing.Optional[ConversationChargingCommonModel] = None
    phone_call: typing.Optional[ConversationHistoryMetadataCommonModelPhoneCall] = None
    termination_reason: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
